@@ -10,8 +10,10 @@ function(X,X_dimensions,colTotal,rowTotal,grandTotal,weights=NULL,masses=NULL){
 		weights = rowCenter^-1
 	}
 	#W = diag(weights) 
-	rowProfiles <- X/((rowSums(X))%*%matrix(1,1,ncol(X)))
-	deviations = rowProfiles - (repmat(1,X_dimensions[1],1)%*%rowCenter)
+	#rowProfiles <- X/((rowSums(X))%*%matrix(1,1,ncol(X)))
+	rowProfiles <- rowNorms(X,type='ca')
+	#deviations = rowProfiles - (repmat(1,X_dimensions[1],1)%*%rowCenter)
+	deviations <- rowProfiles - matrix(rowCenter,X_dimensions[1],X_dimensions[2],byrow=TRUE)
 	#return(list(rowCenter=rowCenter,masses=masses,M=M,weights=weights,W=W,rowProfiles=rowProfiles,deviations=deviations))
 	return(list(rowCenter=rowCenter,masses=masses,weights=weights,rowProfiles=rowProfiles,deviations=deviations))
 }
