@@ -9,7 +9,7 @@ function (x,...) {
   cat ("The analysis was performed on ", nrow(res.epGPCA$fi),
        "individuals, described by", nrow(res.epGPCA$fj), "variables\n")
   cat("*The results are available in the following objects:\n\n")
-  res <- array("", c(14, 2), list(1:14, c("name", "description")))
+  res <- array("", c(16, 2), list(1:16, c("name", "description")))
   
   res[1,] <- c("$fi","Factor scores of the rows")
   res[2,] <- c("$di","Squared distances of the rows")
@@ -24,7 +24,9 @@ function (x,...) {
   res[11,] <- c("$M","masses")
   res[12,] <- c("$W","weights")    
   res[13,] <- c("$pdq","GSVD data")
-  res[14,] <- c("$X","X matrix to decompose")  
+  res[14,] <- c("$X","X matrix to decompose")
+  res[15,] <- c("$center","Center of X") 
+  res[16,] <- c("$scale","Scale factor of X")      
     
   print(res)
 
